Index: sasmodels/compare.py
===================================================================
--- sasmodels/compare.py	(revision 050c2c8abb4eeedec15c3dc03d57bcbc440e5adc)
+++ sasmodels/compare.py	(revision bb2d187bb2ab971bfa2283dc7e6225a4764cc649)
@@ -312,8 +312,8 @@
         name = name.split('*')[0]
 
-    if name == 'capped_cylinder' and pars['cap_radius'] < pars['radius']:
-        pars['radius'], pars['cap_radius'] = pars['cap_radius'], pars['radius']
-    if name == 'barbell' and pars['bell_radius'] < pars['radius']:
-        pars['radius'], pars['bell_radius'] = pars['bell_radius'], pars['radius']
+    if name == 'capped_cylinder' and pars['radius_cap'] < pars['radius']:
+        pars['radius'], pars['radius_cap'] = pars['radius_cap'], pars['radius']
+    if name == 'barbell' and pars['radius_bell'] < pars['radius']:
+        pars['radius'], pars['radius_bell'] = pars['radius_bell'], pars['radius']
 
     # Limit guinier to an Rg such that Iq > 1e-30 (single precision cutoff)
Index: sasmodels/models/adsorbed_layer.py
===================================================================
--- sasmodels/models/adsorbed_layer.py	(revision 52ec91efe1982286cb988963ccb41671833fc098)
+++ sasmodels/models/adsorbed_layer.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,7 +1,6 @@
-#adsorbed_layer model
-#conversion of Core2ndMomentModel.py
-#converted by Steve King, Mar 2016
+r"""
+Definition
+----------
 
-r"""
 This model describes the scattering from a layer of surfactant or polymer
 adsorbed on large, smooth, notionally spherical particles under the conditions
@@ -19,7 +18,4 @@
 the mean of the density distribution (ie, the distance of the centre-of-mass
 of the distribution from the interface), $\sigma = \sqrt{t^2/12}$.
-
-Definition
-----------
 
 .. math::
@@ -44,9 +40,19 @@
 calculation is exact).
 
+The code for this model is based originally on a a fortran implementation by
+Steve King at ISIS in the SANDRA package c. 1990.
+
 References
 ----------
 
-S King, P Griffiths, J Hone, and T Cosgrove,
-*SANS from Adsorbed Polymer Layers*, *Macromol. Symp.*, 190 (2002) 33-42.
+.. [#] S King, P Griffiths, J Hone, and T Cosgrove, *SANS from Adsorbed Polymer
+   Layers*, *Macromol. Symp.*, 190 (2002) 33-42.
+
+Authorship and Verification
+----------------------------
+
+* **Author:** Jae-Hi Cho **Date:** pre 2010
+* **Last Modified by:** Paul Kienzle **Date:** April 14, 2016
+* **Last Reviewed by:** Steve King **Date:** March 18, 2016
 """
 
@@ -80,11 +86,4 @@
 def Iq(q, second_moment, adsorbed_amount, density_shell, radius,
        volfraction, sld_shell, sld_solvent):
-    # pylint: disable = missing-docstring
-    #deltarhosqrd =  (sld_shell - sld_solvent) * (sld_shell - sld_solvent)
-    #numerator =  6.0 * pi * volfraction * (adsorbed_amount * adsorbed_amount)
-    #denominator =  (q * q) * (density_shell * density_shell) * radius
-    #eterm =  exp(-1.0 * (q * q) * (second_moment * second_moment))
-    ##scale by 10^-2 for units conversion to cm^-1
-    #inten =  1.0e-02 * deltarhosqrd * ((numerator / denominator) * eterm)
     with errstate(divide='ignore'):
         aa = ((sld_shell - sld_solvent)/density_shell * adsorbed_amount) / q
Index: sasmodels/models/barbell.py
===================================================================
--- sasmodels/models/barbell.py	(revision 22221346d45e39a667fe231ce7ca5ecfc79b0ac5)
+++ sasmodels/models/barbell.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,5 +1,6 @@
-#barbell model
-# Note: model title and parameter table are inserted automatically
 r"""
+Definition
+----------
+
 Calculates the scattering from a barbell-shaped cylinder.  Like
 :ref:`capped-cylinder`, this is a sphereocylinder with spherical end
@@ -7,7 +8,4 @@
 of the end cap radius lying outside of the cylinder. See the diagram for
 the details of the geometry and restrictions on parameter values.
-
-Definition
-----------
 
 .. figure:: img/barbell_geometry.jpg
@@ -75,4 +73,5 @@
 
 .. figure:: img/cylinder_angle_projection.jpg
+    :width: 600px
 
     Examples of the angles for oriented pp against the detector plane.
@@ -81,7 +80,14 @@
 ----------
 
-H Kaya, *J. Appl. Cryst.*, 37 (2004) 37 223-230
+.. [#] H Kaya, *J. Appl. Cryst.*, 37 (2004) 37 223-230
+.. [#] H Kaya and N R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda
+   and errata)
 
-H Kaya and N R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda and errata)
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Butler **Date:** March 20, 2016
+* **Last Reviewed by:** Paul Butler **Date:** March 20, 2016
 """
 from numpy import inf
Index: sasmodels/models/bcc_paracrystal.py
===================================================================
--- sasmodels/models/bcc_paracrystal.py	(revision 0bef47b278e819df7ea6b572375dd7bc9607227e)
+++ sasmodels/models/bcc_paracrystal.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,13 +1,10 @@
-#bcc paracrystal model
-#note model title and parameter table are automatically inserted
-#note - calculation requires double precision
 r"""
+Definition
+----------
+
 Calculates the scattering from a **body-centered cubic lattice** with
 paracrystalline distortion. Thermal vibrations are considered to be negligible,
 and the size of the paracrystal is infinitely large. Paracrystalline distortion
 is assumed to be isotropic and characterized by a Gaussian distribution.
-
-Definition
-----------
 
 The scattering intensity $I(q)$ is calculated as
@@ -23,6 +20,7 @@
 is the paracrystalline structure factor for a body-centered cubic structure.
 
-Equation (1) of the 1990 reference is used to calculate $Z(q)$, using
-equations (29)-(31) from the 1987 paper for $Z1$, $Z2$, and $Z3$.
+Equation (1) of the 1990 reference\ [#CIT1990]_ is used to calculate $Z(q)$,
+using equations (29)-(31) from the 1987 paper\ [#CIT1987]_ for $Z1$, $Z2$, and
+$Z3$.
 
 The lattice correction (the occupied volume of the lattice) for a
@@ -79,6 +77,5 @@
 The 2D (Anisotropic model) is based on the reference below where $I(q)$ is
 approximated for 1d scattering. Thus the scattering pattern for 2D may not
-be accurate. Note that we are not responsible for any incorrectness of the 2D
-model computation.
+be accurate.
 
 .. figure:: img/bcc_angle_definition.png
@@ -89,9 +86,15 @@
 ----------
 
-Hideki Matsuoka et. al. *Physical Review B*, 36 (1987) 1754-1765
-(Original Paper)
+.. [#CIT1987] Hideki Matsuoka et. al. *Physical Review B*, 36 (1987) 1754-1765
+   (Original Paper)
+.. [#CIT1990] Hideki Matsuoka et. al. *Physical Review B*, 41 (1990) 3854 -3856
+   (Corrections to FCC and BCC lattice structure calculation)
 
-Hideki Matsuoka et. al. *Physical Review B*, 41 (1990) 3854 -3856
-(Corrections to FCC and BCC lattice structure calculation)
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Butler **Date:** September 29, 2016
+* **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
 """
 
@@ -109,4 +112,5 @@
 category = "shape:paracrystal"
 
+#note - calculation requires double precision
 single = False
 
Index: sasmodels/models/be_polyelectrolyte.py
===================================================================
--- sasmodels/models/be_polyelectrolyte.py	(revision 2c74c11fc4544381ecf9949bd1618c67ff624c6d)
+++ sasmodels/models/be_polyelectrolyte.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,10 +1,8 @@
 r"""
-This model calculates the structure factor of a polyelectrolyte solution with
-the RPA expression derived by Borue and Erukhimovich.
-
 Definition
 ----------
-
-The scattering intensity $I(q)$ is calculated as
+This model calculates the structure factor of a polyelectrolyte solution with
+the RPA expression derived by Borue and Erukhimovich\ [#Borue]_.  The scattering intensity
+$I(q)$ is calculated as
 
 .. math::
@@ -36,13 +34,16 @@
 ----------
 
-V Y Borue, I Y Erukhimovich, *Macromolecules*, 21 (1988) 3240
+.. [#Borue] V Y Borue, I Y Erukhimovich, *Macromolecules*, 21 (1988) 3240
+.. [#] J F Joanny, L Leibler, *Journal de Physique*, 51 (1990) 545
+.. [#] A Moussaid, F Schosseler, J P Munch, S Candau, *J. Journal de Physique
+   II France*, 3 (1993) 573
+.. [#] E Raphael, J F Joanny, *Europhysics Letters*, 11 (1990) 179
 
-J F Joanny, L Leibler, *Journal de Physique*, 51 (1990) 545
+Authorship and Verification
+----------------------------
 
-A Moussaid, F Schosseler, J P Munch, S Candau,
-*J. Journal de Physique II France*, 3 (1993) 573
-
-E Raphael, J F Joanny, *Europhysics Letters*, 11 (1990) 179
-
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Kienzle **Date:** July 24, 2016
+* **Last Reviewed by:** Piotr rozyczko **Date:** January 27, 2016
 """
 
Index: sasmodels/models/binary_hard_sphere.py
===================================================================
--- sasmodels/models/binary_hard_sphere.py	(revision 63c6a080288d10935e533a7d4e4bca34f9850511)
+++ sasmodels/models/binary_hard_sphere.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,6 +1,6 @@
 r"""
-
 Definition
 ----------
+
 The binary hard sphere model provides the scattering intensity, for binary
 mixture of hard spheres including hard sphere interaction between those
@@ -61,14 +61,14 @@
 ----------
 
-N W Ashcroft and D C Langreth, *Physical Review*, 156 (1967) 685-692
-[Errata found in *Phys. Rev.* 166 (1968) 934]
+.. [#] N W Ashcroft and D C Langreth, *Physical Review*, 156 (1967) 685-692
+   [Errata found in *Phys. Rev.* 166 (1968) 934]
+.. [#] S R Kline, *J Appl. Cryst.*, 39 (2006) 895
 
-S R Kline, *J Appl. Cryst.*, 39 (2006) 895
+Authorship and Verification
+----------------------------
 
-**Author:** NIST IGOR/DANSE **on:** pre 2010
-
-**Last Modified by:** Paul Butler **on:** March 20, 2016
-
-**Last Reviewed by:** Paul Butler **on:** March 20, 2016
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Butler **Date:** March 20, 2016
+* **Last Reviewed by:** Paul Butler **Date:** March 20, 2016
 """
 
Index: sasmodels/models/broad_peak.py
===================================================================
--- sasmodels/models/broad_peak.py	(revision 40a87fa5096610e24c3ead10299f609e99f093f2)
+++ sasmodels/models/broad_peak.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,3 +1,6 @@
 r"""
+Definition
+----------
+
 This model calculates an empirical functional form for SAS data characterized
 by a broad scattering peak. Many SAS spectra are characterized by a broad peak
@@ -9,7 +12,4 @@
 between the scattering inhomogeneities (such as in lamellar, cylindrical, or
 spherical morphologies, or for bicontinuous structures).
-
-Definition
-----------
 
 The scattering intensity $I(q)$ is calculated as
@@ -33,5 +33,10 @@
 None.
 
-*2013/09/09 - Description reviewed by King, S and Parker, P.*
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul kienle **Date:** July 24, 2016
+* **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
 """
 
Index: sasmodels/models/capped_cylinder.py
===================================================================
--- sasmodels/models/capped_cylinder.py	(revision 22221346d45e39a667fe231ce7ca5ecfc79b0ac5)
+++ sasmodels/models/capped_cylinder.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,3 +1,6 @@
 r"""
+Definitions
+-----------
+
 Calculates the scattering from a cylinder with spherical section end-caps.
 Like :ref:`barbell`, this is a sphereocylinder with end caps that have a
@@ -6,7 +9,4 @@
 lens when the length of the cylinder $L=0$. See the diagram for the details
 of the geometry and restrictions on parameter values.
-
-Definitions
------------
 
 .. figure:: img/capped_cylinder_geometry.jpg
@@ -76,4 +76,5 @@
 
 .. figure:: img/cylinder_angle_projection.jpg
+    :width: 600px
 
     Examples of the angles for oriented 2D cylinders against the detector plane.
@@ -82,7 +83,14 @@
 ----------
 
-H Kaya, *J. Appl. Cryst.*, 37 (2004) 223-230
+.. [#] H Kaya, *J. Appl. Cryst.*, 37 (2004) 223-230
+.. [#] H Kaya and N-R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda 
+   and errata)
 
-H Kaya and N-R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda and errata)
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Butler **Date:** September 30, 2016
+* **Last Reviewed by:** Richard Heenan **Date:** March 19, 2016
 """
 from numpy import inf
Index: sasmodels/models/core_multi_shell.py
===================================================================
--- sasmodels/models/core_multi_shell.py	(revision 7b68dc576b7995dbf041602384c63c354ea857b5)
+++ sasmodels/models/core_multi_shell.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -33,15 +33,15 @@
 References
 ----------
-See the :ref:`core-shell-sphere` model documentation.
 
-L A Feigin and D I Svergun,
-*Structure Analysis by Small-Angle X-Ray and Neutron Scattering*,
-Plenum Press, New York, 1987.
+.. [#] See the :ref:`core-shell-sphere` model documentation.
+.. [#] L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and Neutron Scattering*,
+   Plenum Press, New York, 1987.
 
-**Author:** NIST IGOR/DANSE **on:** pre 2010
+Authorship and Verification
+----------------------------
 
-**Last Modified by:** in progress **on:** March 20, 2016
-
-**Last Reviewed by:** in progress **on:** March 20, 2016
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Kienzle **Date:** September 12, 2016
+* **Last Reviewed by:** Under Review **Date:** as of October 5, 2016
 """
 
Index: sasmodels/models/core_shell_bicelle.py
===================================================================
--- sasmodels/models/core_shell_bicelle.py	(revision 22221346d45e39a667fe231ce7ca5ecfc79b0ac5)
+++ sasmodels/models/core_shell_bicelle.py	(revision b0c42719ac9096c35137bf644db59e1c5915b06b)
@@ -1,4 +1,3 @@
 r"""
-
 Definition
 ----------
@@ -13,6 +12,6 @@
 .. figure:: img/core_shell_bicelle_geometry.png
 
-    (Graphic from DOI: 10.1039/C0NP00002G, note however that the model here
-    calculates for rectangular, not curved, rims.)
+    Core shell geometry (Graphic from ref [#Matusmori]_).
+    Note however that the model here calculates for rectangular, not curved, rims.
 
 The output of the 1D scattering intensity function for randomly oriented
@@ -28,4 +27,5 @@
 
 .. figure:: img/cylinder_angle_projection.jpg
+    :width: 600px
 
     Examples of the angles for oriented pp against the detector plane.
@@ -34,7 +34,15 @@
 ----------
 
-L A Feigin and D I Svergun,
-*Structure Analysis by Small-Angle X-Ray and Neutron Scattering,*
-Plenum Press, New York, (1987)
+.. [#Matusmori] `N Matsumori and M Murata <http://dx.doi.org/10.1039/C0NP0000
+   2G>`_, *Nat. Prod. Rep.* 27 (2010) 1480-1492
+.. [#] L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and
+   Neutron Scattering,* Plenum Press, New York, (1987)
+
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Paul Butler **Date:** Septmber 30, 2016
+* **Last Reviewed by:** Under Review **Date:** October 5, 2016
 
 """
Index: sasmodels/models/hollow_cylinder.c
===================================================================
--- sasmodels/models/hollow_cylinder.c	(revision a8072067ae8a224e45d23ba71f663aadbe1ba4a9)
+++ sasmodels/models/hollow_cylinder.c	(revision aea2e2ab3f11c42b7fc1a72a02b6784076c41d3a)
@@ -1,10 +1,10 @@
-double form_volume(double radius, double radius_core, double length);
+double form_volume(double radius, double thickness, double length);
 
-double Iq(double q, double radius, double radius_core, double length, double sld,
+double Iq(double q, double radius, double thickness, double length, double sld,
 	double solvent_sld);
-double Iqxy(double qx, double qy, double radius, double radius_core, double length, double sld,
+double Iqxy(double qx, double qy, double radius, double thickness, double length, double sld,
 	double solvent_sld, double theta, double phi);
 
-#define INVALID(v) (v.radius_core >= v.radius)
+//#define INVALID(v) (v.radius_core >= v.radius)
 
 // From Igor library
@@ -27,10 +27,10 @@
 
 static double _hollow_cylinder_kernel(
-    double q, double radius_core, double radius, double length, double dum)
+    double q, double radius, double thickness, double length, double dum)
 {
     const double qs = q*sqrt(1.0-dum*dum);
-    const double lam1 = sas_J1c(radius*qs);
-    const double lam2 = sas_J1c(radius_core*qs);
-    const double gamma_sq = square(radius_core/radius);
+    const double lam1 = sas_J1c((radius+thickness)*qs);
+    const double lam2 = sas_J1c(radius*qs);
+    const double gamma_sq = square(radius/(radius+thickness));
     //Note: lim_{r -> r_c} psi = J0(radius_core*qs)
     const double psi = (lam1 - gamma_sq*lam2)/(1.0 - gamma_sq);	//SRK 10/19/00
@@ -41,5 +41,5 @@
 
 static double hollow_cylinder_analytical_2D_scaled(
-    double q, double q_x, double q_y, double radius, double radius_core,
+    double q, double q_x, double q_y, double radius, double thickness,
     double length, double sld, double solvent_sld, double theta, double phi)
 {
@@ -65,7 +65,7 @@
     cos_val = cyl_x*q_x + cyl_y*q_y;// + cyl_z*q_z;
 
-    answer = _hollow_cylinder_kernel(q, radius_core, radius, length, cos_val);
+    answer = _hollow_cylinder_kernel(q, radius, thickness, length, cos_val);
 
-    vol = form_volume(radius, radius_core, length);
+    vol = form_volume(radius, thickness, length);
     answer = hollow_cylinder_scaling(answer, delrho, vol);
 
@@ -74,12 +74,12 @@
 
 
-double form_volume(double radius, double radius_core, double length)
+double form_volume(double radius, double thickness, double length)
 {
-    double v_shell = M_PI*length*(radius*radius-radius_core*radius_core);
+    double v_shell = M_PI*length*((radius+thickness)*(radius+thickness)-radius*radius);
     return(v_shell);
 }
 
 
-double Iq(double q, double radius, double radius_core, double length,
+double Iq(double q, double radius, double thickness, double length,
     double sld, double solvent_sld)
 {
@@ -95,10 +95,10 @@
     for (i=0;i<76;i++) {
         zi = ( Gauss76Z[i] * (upper-lower) + lower + upper )/2.0;
-        inter = Gauss76Wt[i] * _hollow_cylinder_kernel(q, radius_core, radius, length, zi);
+        inter = Gauss76Wt[i] * _hollow_cylinder_kernel(q, radius, thickness, length, zi);
         summ += inter;
     }
 
     norm = summ*(upper-lower)/2.0;
-    volume = form_volume(radius, radius_core, length);
+    volume = form_volume(radius, thickness, length);
     delrho = solvent_sld - sld;
     answer = hollow_cylinder_scaling(norm, delrho, volume);
@@ -108,8 +108,8 @@
 
 
-double Iqxy(double qx, double qy, double radius, double radius_core,
+double Iqxy(double qx, double qy, double radius, double thickness,
     double length, double sld, double solvent_sld, double theta, double phi)
 {
     const double q = sqrt(qx*qx+qy*qy);
-    return hollow_cylinder_analytical_2D_scaled(q, qx/q, qy/q, radius, radius_core, length, sld, solvent_sld, theta, phi);
+    return hollow_cylinder_analytical_2D_scaled(q, qx/q, qy/q, radius, thickness, length, sld, solvent_sld, theta, phi);
 }
Index: sasmodels/models/hollow_cylinder.py
===================================================================
--- sasmodels/models/hollow_cylinder.py	(revision a8072067ae8a224e45d23ba71f663aadbe1ba4a9)
+++ sasmodels/models/hollow_cylinder.py	(revision aea2e2ab3f11c42b7fc1a72a02b6784076c41d3a)
@@ -1,6 +1,6 @@
 r"""
 This model provides the form factor, $P(q)$, for a monodisperse hollow right
-angle circular cylinder (tube) where the form factor is normalized by the
-volume of the tube
+angle circular cylinder (rigid tube) where the form factor is normalized by the
+volume of the tube (i.e. not by the external volume).
 
 .. math::
@@ -21,5 +21,5 @@
     P(q)           &= (\text{scale})V_\text{shell}\Delta\rho^2
             \int_0^{1}\Psi^2
-            \left[q_z, R_\text{shell}(1-x^2)^{1/2},
+            \left[q_z, R_\text{outer}(1-x^2)^{1/2},
                        R_\text{core}(1-x^2)^{1/2}\right]
             \left[\frac{\sin(qHx)}{qHx}\right]^2 dx \\
@@ -27,6 +27,6 @@
             \left[ \Lambda(qy) - \gamma^2\Lambda(qz) \right] \\
     \Lambda(a)     &= 2 J_1(a) / a \\
-    \gamma         &= R_\text{core} / R_\text{shell} \\
-    V_\text{shell} &= \pi \left(R_\text{shell}^2 - R_\text{core}^2 \right)L \\
+    \gamma         &= R_\text{core} / R_\text{outer} \\
+    V_\text{shell} &= \pi \left(R_\text{outer}^2 - R_\text{core}^2 \right)L \\
     J_1(x)         &= (\sin(x)-x\cdot \cos(x)) / x^2
 
@@ -35,9 +35,8 @@
 
 **NB**: The 2nd virial coefficient of the cylinder is calculated
-based on the radius and 2 length values, and used as the effective radius
-for $S(q)$ when $P(q) \cdot S(q)$ is applied.
+based on the outer radius and full length, which give an the effective radius
+for structure factor $S(q)$ when $P(q) \cdot S(q)$ is applied.
 
-In the parameters, the contrast represents SLD :sub:`shell` - SLD :sub:`solvent`
-and the *radius* is $R_\text{shell}$ while *radius_core* is $R_\text{core}$.
+In the parameters,the *radius* is $R_\text{core}$ while *thickness* is $R_\text{outer} - R_\text{core}$.
 
 To provide easy access to the orientation of the core-shell cylinder, we define
@@ -50,4 +49,13 @@
 L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and
 Neutron Scattering*, Plenum Press, New York, (1987)
+
+Authorship and Verification
+----------------------------
+
+* **Author:** NIST IGOR/DANSE **Date:** pre 2010
+* **Last Modified by:** Richard Heenan **Date:** October 06, 2016 
+   (reparametrised to use thickness, not outer radius)
+* **Last Reviewed by:** Richard Heenan **Date:** October 06, 2016
+
 """
 
@@ -58,6 +66,6 @@
 description = """
 P(q) = scale*<f*f>/Vol + background, where f is the scattering amplitude.
-radius_core = the radius of core
-radius = the radius of shell
+radius = the radius of core
+thickness = the thickness of shell
 length = the total length of the cylinder
 sld = SLD of the shell
@@ -69,7 +77,7 @@
 #   ["name", "units", default, [lower, upper], "type","description"],
 parameters = [
-    ["radius",      "Ang",     30.0, [0, inf],    "volume",      "Cylinder radius"],
-    ["radius_core", "Ang",     20.0, [0, inf],    "volume",      "Hollow core radius"],
-    ["length",      "Ang",    400.0, [0, inf],    "volume",      "Cylinder length"],
+    ["radius",      "Ang",     20.0, [0, inf],    "volume",      "Cylinder core radius"],
+    ["thickness",   "Ang",     10.0, [0, inf],    "volume",      "Cylinder wall thickness"],
+    ["length",      "Ang",    400.0, [0, inf],    "volume",      "Cylinder total length"],
     ["sld",         "1/Ang^2",  6.3, [-inf, inf], "sld",         "Cylinder sld"],
     ["sld_solvent", "1/Ang^2",  1,   [-inf, inf], "sld",         "Solvent sld"],
@@ -82,14 +90,15 @@
 
 # pylint: disable=W0613
-def ER(radius, radius_core, length):
+def ER(radius, thickness, length):
     """
     :param radius:      Cylinder radius
     :param radius_core: Hollow core radius, UNUSED
     :param length:      Cylinder length
     :return:            Effective radius
     """
-    if radius == 0 or length == 0:
+    router = radius + thickness
+    if router == 0 or length == 0:
         return 0.0
-    len1 = radius
+    len1 = router
     len2 = length/2.0
     term1 = len1*len1*2.0*len2/2.0
@@ -99,22 +108,23 @@
     return diam
 
-def VR(radius, radius_core, length):
+def VR(radius, thickness, length):
     """
     :param radius:      Cylinder radius
-    :param radius_core: Hollow core radius
+    :param thickness:   Cylinder wall thickness
     :param length:      Cylinder length
     :return:            Volf ratio for P(q)*S(q)
     """
-    vol_core = pi*radius_core*radius_core*length
-    vol_total = pi*radius*radius*length
+    router = radius + thickness
+    vol_core = pi*radius*radius*length
+    vol_total = pi*router*router*length
     vol_shell = vol_total - vol_core
     return vol_shell, vol_total
 
 # parameters for demo
-demo = dict(scale=1.0, background=0.0, length=400.0, radius=30.0,
-            radius_core=20.0, sld=6.3, sld_solvent=1, theta=90, phi=0,
+demo = dict(scale=1.0, background=0.0, length=400.0, radius=20.0,
+            thickness=10, sld=6.3, sld_solvent=1, theta=90, phi=0,
+            thickness_pd=0.2, thickness_pd_n=9,
+            length_pd=.2, length_pd_n=10,
             radius_pd=.2, radius_pd_n=9,
-            length_pd=.2, length_pd_n=10,
-            radius_core_pd=.2, radius_core_pd_n=9,
             theta_pd=10, theta_pd_n=5,
            )
@@ -122,5 +132,5 @@
 # Parameters for unit tests
 tests = [
-    [{"radius": 30.0}, 0.00005, 1764.926],
+    [{}, 0.00005, 1764.926],
     [{}, 'VR', 1.8],
     [{}, 0.001, 1756.76]
@@ -82,14 +90,15 @@
     """
-    :param radius:      Cylinder radius
-    :param radius_core: Hollow core radius, UNUSED
+    :param radius:      Cylinder core radius
+    :param thickness:   Cylinder wall thickness
     :param length:      Cylinder length
     :return:            Effective radius
